{
  description = "Nixos configuration for Timo";

  inputs = {
    nixpkgs.url = "nixpkgs/nixos-24.11";

    nixpkgs-unstable.url = "nixpkgs/nixos-unstable";

    home-manager = {
      url = "github:nix-community/home-manager/release-24.11";
      inputs.nixpkgs.follows = "nixpkgs";
    };

    nixos-hardware.url = "github:NixOS/nixos-hardware/master";

    nix-colors.url = "github:misterio77/nix-colors";

    stylix.url = "github:danth/stylix/release-24.11";

    nixpkgs.follows = "nixos-cosmic/nixpkgs-stable";

    nixos-cosmic = {
      url = "github:lilyinstarlight/nixos-cosmic";
    };

    sops-nix.url = "github:Mic92/sops-nix";

    disko.url = "github:nix-community/disko";
    disko.inputs.nixpkgs.follows = "nixpkgs";
  };

  outputs = inputs@{ self, nixpkgs, nixpkgs-unstable, home-manager, nix-colors, stylix, nixos-cosmic, sops-nix, disko, ... }:
  let
    system = "x86_64-linux";
    system-arm = "aarch64-linux";
    overlay-unstable = final: prev: {
      unstable = import nixpkgs-unstable {
        config.allowUnfree = true;
        localSystem = { inherit system; };
      };
    };
    overlay-unstable-arm = final: prev: {
      unstable = import nixpkgs-unstable {
        config.allowUnfree = true;
        localSystem = { inherit system-arm; };
      };
    };
  in 
  {
    nixosConfigurations = {
      # nixos-anywhere --flake .#p-th-rpi-01 --generate-hardware-config nixos-generate-config ./hosts/p-th-rpi-01/hardware-configuration.nix
      p-th-rpi-01 = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          disko.nixosModules.disko
          inputs.nixos-hardware.nixosModules.raspberry-pi-4

          ./hosts/p-th-rpi-01        ];
      };

      ti-clt-lpt01 = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          inputs.nixos-hardware.nixosModules.framework-13-7040-amd

          ./hosts/ti-clt-lpt01
        ];
      };

      ch-clt-dsk01 = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          ./hosts/ch-clt-dsk01
        ];
      };

      ti-clt-tbl01 = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          inputs.nixos-hardware.nixosModules.microsoft-surface-go

          ./hosts/ti-clt-tbl01
        ];
      };

      ti-clt-dsk01 = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          ./hosts/ti-clt-dsk01
        ];
      };

      v-th-ctr-01 = nixpkgs.lib.nixosSystem {
        system = "x86_64-linux";
        specialArgs = { inherit inputs; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })
          ./hosts/v-th-ctr-01
        ];
      };
    };

    homeConfigurations = {
      "xeovalyte@ti-clt-lpt01" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = { inherit inputs nix-colors; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          ./hosts/ti-clt-lpt01/home.nix
        ];
      };

      "kiiwy@ch-clt-dsk01" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = { inherit inputs nix-colors; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })

          ./hosts/ch-clt-dsk01/home.nix
        ];
      };

      "xeovalyte@ti-clt-tbl01" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = { inherit inputs nix-colors; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })
      
          ./hosts/ti-clt-tbl01/home.nix
        ];
      };

      "xeovalyte@ti-clt-dsk01" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = { inherit inputs nix-colors; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })
        
          ./hosts/ti-clt-dsk01/home.nix
        ];
      };

      "deploy@v-th-ctr-01" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.x86_64-linux;
        extraSpecialArgs = { inherit inputs nix-colors; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })
        
          ./hosts/v-th-ctr-01/home.nix
        ];
      };

      "deploy@p-th-rpi-01" = home-manager.lib.homeManagerConfiguration {
        pkgs = nixpkgs.legacyPackages.aarch64-linux;
        extraSpecialArgs = { inherit inputs nix-colors; };
        modules = [
          ({ config, pkgs, ... }: { nixpkgs.overlays = [ overlay-unstable ]; })
        
          ./hosts/p-th-rpi-01/home.nix
        ];
      };
    };
  };
}

