{ ... }:

let
  hostname = "p-th-rpi-01";
  username = "deploy";
  authorizedKeys = [
    ""
  ];
in
{
  imports = [
    ./hardware-configuration.nix

    # Import modules
    ../../modules/system/default.nix
  ];

  settings = {
    display-manager = "none";
    desktop-environments = {
      cosmic.enable = false;
      hyprland.enable = false;
      gnome.enable = false;
    };
    applications = {
      common.enable = true;
      steam.enable = false;
      thunar.enable = false;
    };
    services = {
      docker.enable = false;
      podman.enable = true;
      quickemu.enable = false;
      sunshine.enable = false;
      garbage-collection.enable = true;
      incus.enable = false;
      ssh.enable = true;
    };
    hardware = {
      fprint.enable = false;
      printing.enable = false;
      bluetooth.enable = false;
      firewall.enable = true;
      locale.enable = true;
      nvidia.enable = false;
    };
  };

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "https://nix-community.cachix.org"
      "https://cosmic.cachix.org/"
    ];

    trusted-public-keys = [
      "cosmic.cachix.org-1:Dya9IyXD4xdBehWjrkPv6rtxpmMdRel02smYzA85dPE="
    ];
  };

  # Use the extlinux boot loader. (NixOS wants to enable GRUB by default)
  boot.loader.grub.enable = false;
  # Enables the generation of /boot/extlinux/extlinux.conf
  boot.loader.generic-extlinux-compatible.enable = true;

  services.openssh.enable = true;
  users.users.root.openssh.authorizedKeys.keys = [
    "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIM/FIQBczDV/niK3a2/2kK8BMH/8qBipSdp73C+HKR0e xeovalyte@ti-clt-dsk01"
  ];

  networking.hostName = hostname; # Define your hostname.

  networking.firewall = {
    enable = true;
    allowedTCPPorts = [ 1080 1443 1053 ];
    allowedUDPPorts = [ 1080 1443 1053 ];
  };

  networking.hosts = {
    "127.0.0.1" = [ "tbmrs.nl" ];
  };

  users.users.${username} = {
    isNormalUser = true;
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
    linger = true;
  };

  nix.settings.trusted-users = [ "root" "${username}" ];

  system.stateVersion = "24.05";
}
